function playUpperAnims(speed) {
  const upperAnim = 'upper_' + speed;
  const noseAnim = 'nose_' + speed;
  const blindfoldAnim = 'blindfold_' + speed;
  const hairFrontAnim = 'hair_front_' + speed;
  const hairBackAnim = 'hair_back_' + speed;
  const hairShadowAnim = 'hair_shadow_' + speed;

  upper.anims.play(upperAnim);
  nose.anims.play(noseAnim);
  blindfold.anims.play(blindfoldAnim);
  hairFront.anims.play(hairFrontAnim);
  hairBack.anims.play(hairBackAnim);
  hairShadow.anims.play(hairShadowAnim);
}

function setUpperTexture() {
  const upperSprite = clothingOptions[0];
  const hairFrontSprite = hairstyleOptions[0] + '_front';
  const hairBackSprite = hairstyleOptions[0] + '_back';
  const hairShadowSprite = hairstyleOptions[0] + '_shadow';
  upper.setTexture(upperSprite, 2);
  nose.setTexture('kuri_nose', 2);
  blindfold.setTexture('blindfold', 2);
  hairFront.setTexture(hairFrontSprite, 2);
  hairBack.setTexture(hairBackSprite, 2);
  hairShadow.setTexture(hairShadowSprite, 2);
}

function setStaticExpression(eyesImage, mouthImage) {
  removeListeners();
  idleAnimPlaying = false;
  toolReaction = false;

  if (gagged && mouthImage.includes('tease')) {
    mouthImage = getGaggedTease();
  }

  setUpperTexture();
  eyes.setTexture(eyesImage);
  mouth.setTexture(mouthImage);
}

function playFullExpression(eyesAnim, mouthAnim, speed) {
  removeListeners();
  idleAnimPlaying = false;
  toolReaction = false;

  if (gagged && mouthAnim.includes('tired')) {
    mouthAnim = getGaggedBreathing();
  }
  if (gagged && mouthAnim.includes('laughing')) {
    mouthAnim = getGaggedLaughing(speed);
  }
  else if (gagged && mouthAnim.includes('massage')) {
    mouthAnim = getGaggedMoaning(speed);
  }

  playUpperAnims(speed);
  eyes.anims.play(eyesAnim);
  mouth.anims.play(mouthAnim);
}

function playChainedExpression(eyesTransition, eyesAnim, mouthAnim, speed) {
  removeListeners();
  idleAnimPlaying = false;
  toolReaction = false;

  if (gagged && mouthAnim.includes('tired')) {
    mouthAnim = getGaggedBreathing();
  }
  if (gagged && mouthAnim.includes('laughing')) {
    mouthAnim = getGaggedLaughing(speed);
  }
  else if (gagged && mouthAnim.includes('massage')) {
    mouthAnim = getGaggedMoaning(speed);
  }

  eyes.anims.play(eyesTransition).on('animationcomplete', () => {
    playUpperAnims(speed);
    mouth.anims.play(mouthAnim);
    eyes.anims.play(eyesAnim);
    eyes.removeListener('animationcomplete');
  });
}

function playReversedChainedExpression(eyesTransition, eyesAnim, mouthAnim, speed) {
  removeListeners();
  idleAnimPlaying = false;
  toolReaction = false;

  if (gagged && mouthAnim.includes('tired')) {
    mouthAnim = getGaggedBreathing();
  }
  if (gagged && mouthAnim.includes('laughing')) {
    mouthAnim = getGaggedLaughing(speed);
  }
  else if (gagged && mouthAnim.includes('massage')) {
    mouthAnim = getGaggedMoaning(speed);
  }

  eyes.anims.playReverse(eyesTransition).on('animationcomplete', () => {
    playUpperAnims(speed);
    mouth.anims.play(mouthAnim);
    eyes.anims.play(eyesAnim);
    eyes.removeListener('animationcomplete');
  });
}

function playEyesExpression(eyesAnim) {
  removeListeners();
  idleAnimPlaying = true;
  toolReaction = false;
  eyes.anims.play(eyesAnim);
}

function playMouthExpression(mouthAnim) {
  removeListeners();
  if (gagged) {
    mouthAnim = getGaggedTalking();
  }
  idleAnimPlaying = true;
  toolReaction = false;
  mouth.anims.play(mouthAnim);
}

function playTalkingExpression(talkingLevel, talkingVariant) {
  removeListeners();
  idleAnimPlaying = true;
  toolReaction = false;
  const idleSprites = getIdleSprites();
  let eyesImage = 'talking' + talkingLevel + '-' + talkingVariant + '_eyes';
  let mouthAnim = 'talking' + talkingLevel + '-' + talkingVariant + '_mouth';

  if (gagged) {
    mouthAnim = getGaggedTalking();
  }

  eyes.anims.remove();
  eyes.setTexture(eyesImage);
  mouth.anims.play(mouthAnim).on('animationcomplete', () => {
    idleAnimPlaying = false;
    setStaticExpression(idleSprites[0], idleSprites[1]);
    mouth.removeListener('animationcomplete');
  });
}

function playReactionExpression(eyesImage, mouthAnim) {
  removeListeners();
  removeFaceAnims();
  idleAnimPlaying = true;
  const idleSprites = getIdleSprites();

  if (gagged) {
    mouthAnim = getGaggedTalking();
  }

  mouth.anims.play(mouthAnim).on('animationcomplete', () => {
    idleAnimPlaying = false;
    toolReaction = false;
    setStaticExpression(idleSprites[0], idleSprites[1]);
    mouth.removeListener('animationcomplete');
  });
  eyes.setTexture(eyesImage);
}

function playReactionChainedStart(eyesTransition, eyesImage, mouthAnim) {
  removeListeners();
  removeFaceAnims();
  idleAnimPlaying = true;
  const idleSprites = getIdleSprites();

  if (gagged) {
    mouthAnim = getGaggedTalking();
  }

  eyes.anims.play(eyesTransition).on('animationcomplete', () => {
    mouth.anims.play(mouthAnim).on('animationcomplete', () => {
      idleAnimPlaying = false;
      toolReaction = false;
      annoyed.visible = false;
      setStaticExpression(idleSprites[0], idleSprites[1]);
      mouth.removeListener('animationcomplete');
    });
    eyes.removeListener('animationcomplete');
    eyes.setTexture(eyesImage);
  });
}

function playReversedReactionChainedStart(eyesTransition, eyesImage, mouthAnim) {
  removeListeners();
  removeFaceAnims();
  idleAnimPlaying = true;
  const idleSprites = getIdleSprites();

  if (gagged) {
    mouthAnim = getGaggedTalking();
  }

  eyes.anims.playReverse(eyesTransition).on('animationcomplete', () => {
    mouth.anims.play(mouthAnim).on('animationcomplete', () => {
      idleAnimPlaying = false;
      toolReaction = false;
      annoyed.visible = false;
      setStaticExpression(idleSprites[0], idleSprites[1]);
      mouth.removeListener('animationcomplete');
    });
    eyes.removeListener('animationcomplete');
    eyes.setTexture(eyesImage);
  });
}

function playReactionChainedEnd(eyesTransition, eyesImage, mouthAnim) {
  removeListeners();
  removeFaceAnims();
  idleAnimPlaying = true;
  const idleSprites = getIdleSprites();
  eyes.setTexture(eyesImage);
  
  if (gagged && !mouthAnim.includes('gagged')) {
    mouthAnim = getGaggedTalking();
  }

  mouth.anims.play(mouthAnim).on('animationcomplete', () => {
    mouth.removeListener('animationcomplete');
    eyes.anims.play(eyesTransition).on('animationcomplete', () => {
      idleAnimPlaying = false;
      toolReaction = false;
      annoyed.visible = false;
      setStaticExpression(idleSprites[0], idleSprites[1]);
      eyes.removeListener('animationcomplete');
    })
  });
}

function playReactionChainedBoth(eyesTransition1, eyesTransition2, eyesImage, mouthAnim) {
  removeListeners();
  removeFaceAnims();
  idleAnimPlaying = true;
  const idleSprites = getIdleSprites();

  if (gagged) {
    mouthAnim = getGaggedTalking();
  }

  eyes.anims.play(eyesTransition1).on('animationcomplete', () => {
    eyes.removeListener('animationcomplete');
    mouth.anims.play(mouthAnim).on('animationcomplete', () => {
      mouth.removeListener('animationcomplete');
      eyes.anims.play(eyesTransition2).on('animationcomplete', () => {
        eyes.removeListener('animationcomplete');
        idleAnimPlaying = false;
        toolReaction = false;
        annoyed.visible = false;
        setStaticExpression(idleSprites[0], idleSprites[1]);
      });
    });
    eyes.setTexture(eyesImage);
  })
}

function playTeaseAnim(eyesTransition, eyesImage, mouthImage, reverse = false) {
  if (reverse) {
    eyes.anims.playReverse(eyesTransition).on('animationcomplete', () => {
      setStaticExpression(eyesImage, mouthImage);
    });
  }
  else {
    eyes.anims.play(eyesTransition).on('animationcomplete', () => {
      setStaticExpression(eyesImage, mouthImage);
    });
  }
}

function removeFaceAnims() {
  upper.anims.remove();
  hairFront.anims.remove();
  hairBack.anims.remove();
  hairShadow.anims.remove();
  nose.anims.remove();
  blindfold.anims.remove();
  eyes.anims.remove();
  mouth.anims.remove();
}

function removeListeners() {
  annoyed.visible = false;
  eyes.removeListener('animationcomplete');
  mouth.removeListener('animationcomplete');
}

function getIdleSprites() {
  if (gagged) {
    if (broken) {
      return ['idle4_eyes', 'idle3_gagged'];
    } else if (aroused){
      return ['idle5_eyes', 'idle5_gagged'];
    } else if (maxPleasure > 1500) {
      return ['idle2c_eyes', 'idle1_gagged'];
    } else if (maxPleasure > 750) {
      return ['idle1c_eyes', 'idle1_gagged'];
    } else if (maxDesperation < 1500) {
      return ['idle1_eyes', 'idle1_gagged'];
    } else if (maxDesperation < 3200) {
      return ['idle2_eyes', 'idle2_gagged'];
    } else {
      return ['idle3_eyes', 'idle3_gagged'];
    }
  }
  else {
    if (broken) {
      return ['idle4_eyes', 'idle1_mouth'];
    } else if (aroused){
      return ['idle5_eyes', 'idle5_mouth'];
    } else if (maxPleasure > 1500) {
      return ['idle2c_eyes', 'idle2c_mouth'];
    } else if (maxPleasure > 750) {
      return ['idle1c_eyes', 'idle1c_mouth'];
    } else if (maxDesperation < 1500) {
      return ['idle1_eyes', 'idle1_mouth'];
    } else if (maxDesperation < 3200) {
      return ['idle2_eyes', 'idle1_mouth'];
    } else {
      return ['idle3_eyes', 'idle1_mouth'];
    }
  }
}

function getGaggedTalking() {
  if (aroused) {
    const talkingNum = Phaser.Math.Between(1,3);
    return 'talking_gagged_aroused' + talkingNum;
  }
  else {
    const talkingNum = Phaser.Math.Between(1,3);
    return 'talking_gagged' + talkingNum;
  }
}

function getGaggedLaughing(speed) {
  if (broken || aroused) {
    return 'laughing4_gagged_' + speed;
  } else if (desperation > 3000) {
    return 'laughing3_gagged_' + speed;
  } else if (desperation > 1300) {
    return 'laughing2_gagged_' + speed;
  } else {
    return 'laughing1_gagged_' + speed;
  }
}

function getGaggedMoaning(speed) {
  if (aroused) {
    return 'laughing3_gagged_' + speed;
  }
  else if (maxPleasure > 1500) {
    return 'laughing2_gagged_' + speed;
  }
  else {
    return 'massage1_gagged_' + speed;
  }
}

function getGaggedBreathing() {
  if (broken) {
    return 'tired3_gagged';
  } else if (aroused) {
    return 'tired4_gagged';
  } else if (desperation > 3000) {
    return 'tired2_gagged';
  } else if (desperation > 1300) {
    return 'tired1_gagged';
  } else {
    return 'tired3_gagged';
  }
}

function getGaggedTease() {
  if (broken) {
    return 'tease3_gagged';
  } else if (aroused) {
    return 'tease5_gagged';
  } else if (maxPleasure > 1500) {
    return 'tease6_gagged';
  } else if (desperation > 3000) {
    return 'tease3_gagged';
  } else if (desperation > 1300 || maxPleasure > 1500) {
    return 'tease2_gagged';
  } else {
    return 'tease1_gagged';
  }
}
