//Function for periodically rotating a sprite left or right depending on a collision conditional and alternating direction bool
function rotateObject(sprite, center, rotateSpeed, collision, direction, maxRotation, radius) {
  if ( sprite.angle <= -maxRotation ) {
    collision.bool = true;
    direction.bool = true;
    Phaser.Actions.RotateAroundDistance([sprite], center, rotateSpeed, radius);
    let angleDeg = Math.atan2(sprite.y - center.y, sprite.x - center.x) * 180 / Math.PI;
    sprite.angle = angleDeg+90
  }
  else if ( sprite.angle >= maxRotation ){
    collision.bool = true;
    direction.bool = false;
    Phaser.Actions.RotateAroundDistance([sprite], center, -rotateSpeed, radius);
    let angleDeg = Math.atan2(sprite.y - center.y, sprite.x - center.x) * 180 / Math.PI;
    sprite.angle = angleDeg+90
  }
  else {
    if ( direction.bool ) {
      Phaser.Actions.RotateAroundDistance([sprite], center, rotateSpeed, radius);
      let angleDeg = Math.atan2(sprite.y - center.y, sprite.x - center.x) * 180 / Math.PI;
      sprite.angle = angleDeg+90
    }
    else {
      Phaser.Actions.RotateAroundDistance([sprite], center, -rotateSpeed, radius);
      let angleDeg = Math.atan2(sprite.y - center.y, sprite.x - center.x) * 180 / Math.PI;
      sprite.angle = angleDeg+90
    }
  }
}

function vibrateObject(sprite, center) {
  if ( sprite.angle >= currAngle){
    Phaser.Actions.RotateAroundDistance([sprite], center, -.0015, 100);
    let angleDeg = Math.atan2(sprite.y - center.y, sprite.x - center.x) * 180 / Math.PI;
    sprite.angle = angleDeg+90
  }
  else {
    Phaser.Actions.RotateAroundDistance([sprite], center, .004, 100);
    let angleDeg = Math.atan2(sprite.y - center.y, sprite.x - center.x) * 180 / Math.PI;
    sprite.angle = angleDeg+90
  }
}

//Function to handle foot behavior when being tickled
function tickleFoot(foot, footCenter, altFoot, altFootCenter, altRotationDirection, teaseAnim, tickleAnim) {
  //Start laugh timer
  if (!laughTimerSet) {
    laughTimer = scene.time.addEvent(laughTimerParameters);
    laughTimerSet = true;
  }
  if (still) {
    foot.anims.playReverse(teaseAnim);
    foot.anims.chain(tickleAnim);
  }
  if (!footAnimPlaying) {
    foot.anims.play(tickleAnim);
  }
  if (breatheAnimPlaying) {
    removeFaceAnims();
    breatheAnimPlaying = false;
  }
  footAnimPlaying = true;
  breatheAnimPlaying = false;
  tiredFootAnimPlaying = false;
  teaseAnimPlaying = false;
  //Stop all speech timers
  holdTimer.remove();
  reactionTimer.remove();
  teaseTimer.remove();
  breatheTimer.remove();
  breakTimer.remove();
  idleSpeechTimer.remove();
  teaseTimerSet = false;
  reactionTimerSet = false;
  idleSpeechTimerSet = false;
  givenBreak = false;
  currQuote = '...';
  still = false;
  wasMassaged = false;
  //Set speed of movement
  let rotateSpeed, shakespeed;
  if (broken) {
    rotateSpeed = Phaser.Math.Between(15, 50) / 1000;
    shakeSpeed = Phaser.Math.Between(5,7) / 5000;
  }
  else if (desperation < 1300) {
    rotateSpeed = Phaser.Math.Between(1, 20) / 1000;
    shakeSpeed = Phaser.Math.Between(1,3) / 5000;
  }
  else if (desperation < 3000) {
    rotateSpeed = Phaser.Math.Between(5, 30) / 1000;
    shakeSpeed = Phaser.Math.Between(2,4) / 5000;
  }
  else {
    rotateSpeed = Phaser.Math.Between(10, 40) / 1000;
    shakeSpeed = Phaser.Math.Between(3,5) / 5000;
  }
  if (desperation >= 6000 && oiled && toetied && !aroused) {
    broken = true;
    aroused = false;
    desperation = 4000;
  }
  //Set laugh speech to be displayed based on desperation
  if (broken) {
    speechText.setFontSize(22);
    speechText.setColor('#ff0000');
    wasTired = true;
    if(!laughAnimPlaying) {
      if (tool === 'hands') {
        if (tickleState3) {
          playChainedExpression('breathe2_transition', 'laughing4_eyes', 'laughing4_mouth', 28);
        }
        else if (desperation < 1300) {
          playChainedExpression('broken1_transition', 'laughing4_eyes', 'laughing4_mouth', 28);
        }
        else {
          playFullExpression('laughing4_eyes', 'laughing4_mouth', 28);
        }
      }
      else if (tool === 'brush') {
        if (wasTeased) {
          playChainedExpression('tease4b_transition', 'laughing4b_eyes', 'laughing4b_mouth', 30);
        }
        else if (tickleState3) {
          playChainedExpression('between3b_transition', 'laughing4b_eyes', 'laughing4b_mouth', 30);
        }
        else if (desperation < 1300) {
          playChainedExpression('broken1b_transition', 'laughing4b_eyes', 'laughing4b_mouth', 30);
        }
        else {
          playFullExpression('laughing4b_eyes', 'laughing4b_mouth', 30);
        }
      }
      else if (tool === 'feather') {
        playReversedChainedExpression('breathe4f_transition', 'laughing4f_eyes', 'laughing4f_mouth', 24);
      }
      else if (tool === 'toothbrush') {
        if (tickleState3) {
          playChainedExpression('between3t_transition', 'laughing4t_eyes', 'laughing4t_mouth', 30);
        }
        else {
          playReversedChainedExpression('breathe4t_transition', 'laughing4t_eyes', 'laughing4t_mouth', 30);
        }
      }
      laughAnimPlaying = true;
    }
    if (desperation < 2500) {
      desperation = 2500;
    }
    tickleState3 = false; 
  }
  else if (aroused) {
    speechText.setFontSize(22);
    speechText.setColor('#f725e1');
    if (desperation > 1300) {
      wasTired = true;
    }
    if(!laughAnimPlaying) {
      if (tool === 'hands') {
        if (wasTeased) {
          playChainedExpression('tease1a_transition', 'laughing1a_eyes', 'laughing1a_mouth', 16);
        }
        else if (wasTired) {
          playChainedExpression('breathe1a_transition', 'laughing1a_eyes', 'laughing1a_mouth', 16);
        }
        else if (desperation < 1300) {
          playChainedExpression('laughing1a_transition', 'laughing1a_eyes', 'laughing1a_mouth', 16);
        }
        else {
          playFullExpression('laughing1a_eyes', 'laughing1a_mouth', 16);
        }
      }
      else if (tool === 'brush') {
        if (wasTeased) {
          playChainedExpression('tease1ba_transition', 'laughing1ba_eyes', 'laughing1ba_mouth', 18);
        }
        else if (wasTired) {
          playChainedExpression('breathe1ba_transition', 'laughing1ba_eyes', 'laughing1ba_mouth', 18);
        }
        else if (desperation < 1300) {
          playChainedExpression('laughing1ba_transition', 'laughing1ba_eyes', 'laughing1ba_mouth', 18);
        }
        else {
          playFullExpression('laughing1ba_eyes', 'laughing1ba_mouth', 18);
        }
      }
      else if (tool === 'feather') {
        if (wasTeased) {
          playChainedExpression('tease1fa_transition', 'laughing1fa_eyes', 'laughing1fa_mouth', 14);
        }
        else if (wasTired) {
          playChainedExpression('breathe1fa_transition', 'laughing1fa_eyes', 'laughing1fa_mouth', 14);
        }
        else if (desperation < 1300) {
          playChainedExpression('laughing1fa_transition', 'laughing1fa_eyes', 'laughing1fa_mouth', 14);
        }
        else {
          playFullExpression('laughing1fa_eyes', 'laughing1fa_mouth', 14);
        }
      }
      else if (tool === 'toothbrush') {
        if (wasTired) {
          playChainedExpression('breathe1ta_transition', 'laughing1ta_eyes', 'laughing1ta_mouth', 20);
        }
        else if (desperation < 1300) {
          playChainedExpression('laughing1ta_transition', 'laughing1ta_eyes', 'laughing1ta_mouth', 20);
        }
        else {
          playFullExpression('laughing1ta_eyes', 'laughing1ta_mouth', 20);
        }
      }
      
      laughAnimPlaying = true;
    }
    /*if (desperation < 1700) {
      desperation = 1700;
    }*/
    tickleState3 = false; 
  }
  else if (desperation > 3000) {
    tickleState3 = true;
    wasTired = true;
    if(!laughAnimPlaying) {
      if (tool === 'hands') {
        playReversedChainedExpression('breathe2_transition', 'laughing3_eyes', 'laughing3_mouth', 24);
      }
      else if (tool === 'brush') {
        playReversedChainedExpression('breathe2_transition', 'laughing3b_eyes', 'laughing3b_mouth', 26);
      }
      else if (tool === 'feather') {
        if (tickleState2) {
          playChainedExpression('tease2f_transition', 'laughing3f_eyes', 'laughing3f_mouth', 20);
        }
        else {
          playFullExpression('laughing3f_eyes', 'laughing3f_mouth', 20);
        }
      }
      else if (tool === 'toothbrush') {
        playReversedChainedExpression('breathe2_transition', 'laughing3t_eyes', 'laughing3t_mouth', 26)
      }
      laughAnimPlaying = true;
    }
  }
  else if (desperation > 1300) {
    tickleState2 = true;
    wasTired = true;
    if(!laughAnimPlaying) {
      if (tool === 'hands') {
        if ( wasTeased || tickleState1) {
          playChainedExpression('tease2_transition', 'laughing2_eyes', 'laughing2_mouth', 20);
        }
        else {
          playReversedChainedExpression('breathe1_transition', 'laughing2_eyes', 'laughing2_mouth', 20);
        }
      }
      else if (tool === 'brush') {
        if ( wasTeased ) {
          playReversedChainedExpression('tease2b_transition', 'laughing2b_eyes', 'laughing2b_mouth', 22);

        }
        else {
          playReversedChainedExpression('breathe1b_transition', 'laughing2b_eyes', 'laughing2b_mouth', 22);
        }
      }
      else if (tool === 'feather') {
        if ( wasTeased ) {
          playChainedExpression('tease2f_transition', 'laughing2f_eyes', 'laughing2f_mouth', 16);
        }
        else if (tickleState1) {
          playChainedExpression('tease1f_transition', 'laughing2f_eyes', 'laughing2f_mouth', 16);
        }
        else {
          playReversedChainedExpression('breathe1_transition', 'laughing2f_eyes', 'laughing2f_mouth', 16);
        }
      }
      else if (tool === 'toothbrush') {
        playChainedExpression('laughing2t_transition', 'laughing2t_eyes', 'laughing2t_mouth', 22);
      }
      laughAnimPlaying = true;
    }
  }
  else {
    tickleState1 = true;
    if(!laughAnimPlaying) {
      if (tool === 'hands') {
        if (toolReaction) {
          playChainedExpression('laughing1_transition', 'laughing1_eyes', 'laughing1_mouth', 16);
        }
        else if (wasTeased || idleAnimPlaying) {
          playFullExpression('laughing1_eyes', 'laughing1_mouth', 16);
        }
        else {
          playChainedExpression('laughing1_transition', 'laughing1_eyes', 'laughing1_mouth', 16);
        }
      }
      else if (tool === 'brush') {
        if (idleAnimPlaying || wasTeased) {
          playChainedExpression('laughing1b_transition', 'laughing1b_eyes', 'laughing1b_mouth', 18);
        }
        else {
          playFullExpression('laughing1b_eyes', 'laughing1b_mouth', 18);
        }
      }
      else if (tool === 'feather') {
        if (idleAnimPlaying || wasTeased) {
          playChainedExpression('tease1f_transition', 'laughing1f_eyes', 'laughing1f_mouth', 12);
        }
        else {
          playChainedExpression('laughing1f_transition', 'laughing1f_eyes', 'laughing1f_mouth', 12);
        }
      }
      else if (tool === 'toothbrush') {
        if (idleAnimPlaying || wasTeased) {
          playChainedExpression('laughing1b_transition', 'laughing1t_eyes', 'laughing1t_mouth', 18);
        }
        else {
          playChainedExpression('laughing1t_transition', 'laughing1t_eyes', 'laughing1t_mouth', 18);
        }
      }
      laughAnimPlaying = true;
    }
  }
  //Display laugh
  speechText.setText(currLaugh);
  //Animate objects
  rotateObject(upperContainer, upperCenter, shakeSpeed, shakeCollided, shakeDirection, 1, 200);
  if (!toetied) {
    rotateObject(foot, footCenter, rotateSpeed, footCollided, footRotationDirection, 20, 100);
    rotateObject(altFoot, altFootCenter, .0002, idleCollided, altRotationDirection, 5, 100);
  }
  //Increase desperation over time
  if (!broken && !aroused && (desperation === 5998 
                  || desperation === 5999 
                  || desperation === 3001 
                  || desperation === 1301 
                  || desperation === 1302 
                  || desperation === 3002)) {
    laughAnimPlaying = false;
    desperation += 1
  }
  if (desperation < 4000 && (broken || aroused)) {
    desperation++;
  }
  else if (desperation < 6005 && !broken && !aroused) {
    desperation++;
  }
  //Set pleasure to 0 after being tickled after certain amount of time
  if (desperation > 1500 && !aroused) {
    pleasure = 0;
    maxPleasure = 0;
  }
  wasTeased = false;
}

function scrunchFoot(leftTeaseAnim, rightTeaseAnim) {
  holdTimer.remove();
  reactionTimer.remove();
  teaseTimer = scene.time.addEvent({
    delay: 300,
    callback: function(){
      if (laughAnimPlaying) {
        removeFaceAnims();
        laughAnimPlaying = false;
      }
      if (!teaseAnimPlaying){
        if (broken) {
          if (tool === 'feather') {
            playTeaseAnim('tease4f_transition', 'tease4_eyes', 'tease4_mouth');
          }
          else if (tool === 'brush') {
            playTeaseAnim('tease4b_transition', 'tease4_eyes', 'tease4_mouth');
          }
          else {
            setStaticExpression('tease4_eyes', 'tease4_mouth');
          }
        }
        else if (aroused) {
          if (tool === 'hands') {
            playTeaseAnim('tease1a_transition', 'tease5_eyes', 'tease5_mouth');
          }
          else if (tool === 'brush') {
            playTeaseAnim('tease1ba_transition', 'tease5_eyes', 'tease5_mouth');
          }
          else if (tool === 'feather') {
            playTeaseAnim('tease1fa_transition', 'tease5_eyes', 'tease5_mouth');
          }
          else {
            setStaticExpression('tease5_eyes', 'tease5_mouth');
          }
        }
        else if(desperation > 3000) {
          if (tool === 'brush' || tool === 'hands') {
            playTeaseAnim('breathe2_transition', 'tease3_eyes', 'tease3_mouth');
          }
          else {
            setStaticExpression('tease3_eyes', 'tease3_mouth');
          }
        }
        else if(desperation > 1300) {
          if ( tool === 'brush') {
            playTeaseAnim('tease2b_transition', 'tease2_eyes', 'tease2_mouth');
          }
          else if ( tool === 'feather'){
            playTeaseAnim('tease2f_transition', 'tease2_eyes', 'tease2_mouth');
          }
          else {
            playTeaseAnim('tease2_transition', 'tease2_eyes', 'tease2_mouth');
          }
        }
        else {
          if ( tool === 'feather') {
            playTeaseAnim('tease1f_transition', 'tease1_eyes', 'tease1_mouth');
          }
          else if ( tool === 'brush') {
            playTeaseAnim('laughing1b_transition', 'tease1_eyes', 'tease1_mouth', true);
          }
          else {
            setStaticExpression('tease1_eyes', 'tease1_mouth');
          }
        }
      }

      if (leftTickled) {
        leftFoot.anims.play(leftTeaseAnim);
      }
      if (rightTickled) {
        rightFoot.anims.play(rightTeaseAnim);
      }

      setTickleTeaseText();
      teaseAnimPlaying = true;

      still = true;
      wasTeased = true;
      tickleState1 = false;
      tickleState2 = false;
      tickleState3 = false;
    },
    callbackScope: scene
  });
  if (leftTickled) {
    currAngle = leftFoot.angle;
  }
  if (rightTickled) {
    currAngle = rightFoot.angle;
  }
  teaseTimerSet = true;
  reactionTimerSet = false;
}

//Function to handle behavior when given foot rub
function massageFoot(foot, footCenter, altFoot, altFootCenter, altRotationDirection, massageAnim, teaseAnim) {
  if (!laughTimerSet) {
    laughTimer = scene.time.addEvent(laughTimerParameters);
    laughTimerSet = true;
  }
  if (still) {
    foot.anims.playReverse(teaseAnim);
    foot.anims.chain(massageAnim);
  }
  if (!footAnimPlaying) {
    foot.anims.play(massageAnim);
  }
  //Stop all speech timers from completing
  holdTimer.remove();
  reactionTimer.remove();
  teaseTimer.remove();
  breatheTimer.remove();
  breakTimer.remove();
  idleSpeechTimer.remove();
  teaseTimerSet = false;
  reactionTimerSet = false;
  idleSpeechTimerSet = false;
  givenBreak = false;
  currQuote = '...';
  still = false;
  footAnimPlaying = true;
  teaseAnimPlaying = false;
  //Set movement speed of rotation
  let rotateSpeed, shakeSpeed;
  if (aroused) {
    rotateSpeed = Phaser.Math.Between(10, 20) / 1000;
    shakeSpeed = Phaser.Math.Between(3,7) / 5000;
  }
  else if (pleasure > 1500) {
    rotateSpeed = Phaser.Math.Between(5, 15) / 1000;
    shakeSpeed = Phaser.Math.Between(2,4) / 5000;
  }
  else {
    rotateSpeed = Phaser.Math.Between(1, 5) / 1000;
    shakeSpeed = Phaser.Math.Between(1,2) / 5000;
  }

  if (pleasure >= 3500 && !broken) {
    aroused = true;
    broken = false;
  }
  //Set and display speech for foot rub
  if (broken) {
    if (!laughAnimPlaying) {
      if (wasTeased || idleAnimPlaying) {
        if (tool === 'wand') {
          playChainedExpression('massage1w_broken_tease_transition', 'massage1w_broken_eyes', 'massage1w_mouth', 14);
        }
        else if (tool === 'tongue') {
          playChainedExpression('massage1t_broken_tease_transition', 'massage1t_broken_eyes', 'massage1t_mouth', 12);
        }
        else {
          playFullExpression('massage1_eyes', 'massage1_mouth', 10);
        }
      }
      else {
        if (tool === 'wand') {
          playChainedExpression('massage1w_broken_transition', 'massage1w_broken_eyes', 'massage1w_mouth', 14);
        }
        else if (tool === 'tongue') {
          playChainedExpression('massage1t_broken_transition', 'massage1t_broken_eyes', 'massage1t_mouth', 12);
        }
        else if (tool === 'hands') {
          playChainedExpression('broken_massage_transition', 'massage1_eyes', 'massage1_mouth', 10);
        }
      }
      laughAnimPlaying = true;
    }
  }
  else if (aroused) {
    speechText.setFontSize(22);
    speechText.setColor('#f725e1');
    if (!laughAnimPlaying) {
      if (tool === 'wand') {
        if (wasTeased || massageState2) {
          playChainedExpression('massage3w_tease_transition', 'massage3w_eyes', 'massage3w_mouth', 18);
        }
        else {
          playChainedExpression('massage3w_transition', 'massage3w_eyes', 'massage3w_mouth', 18);
        }
      }
      else if (tool === 'tongue') {
        if (wasTeased || massageState2) {
          playChainedExpression('massage3t_tease_transition', 'massage3t_eyes', 'massage3t_mouth', 16);
        }
        else {
          playChainedExpression('massage3t_transition', 'massage3t_eyes', 'massage3t_mouth', 16);
        }
      }
      else {
        if (wasTeased) {
          playChainedExpression('massage3_tease_transition', 'massage3_eyes', 'massage3_mouth', 14);
        }
        else if (massageState2) {
          playChainedExpression('massage2_between_transition', 'massage3_eyes', 'massage3_mouth', 14);
        }
        else {
          playChainedExpression('massage3_transition', 'massage3_eyes', 'massage3_mouth', 14);
        }
      }
      laughAnimPlaying = true;
    }
  } 
  else if (maxPleasure > 1500) {
    massageState2 = true;
    if (!laughAnimPlaying) {
      if (tool === 'wand') {
        playChainedExpression('massage2w_transition', 'massage2w_eyes', 'massage2w_mouth', 16);
      }
      else if (tool === 'tongue') {
        if (wasTeased || idleAnimPlaying) {
          playFullExpression('massage2t_eyes', 'massage2t_mouth', 14);
        }
        else if (massageState1) {
          playChainedExpression('massage2t_tease_transition', 'massage2t_eyes', 'massage2t_mouth', 14);
        }
        else {
          playChainedExpression('massage2t_transition', 'massage2t_eyes', 'massage2t_mouth', 14);
        }
      }
      else {
        if (wasTeased || massageState1) {
          playChainedExpression('massage2_tease_transition', 'massage2_eyes', 'massage2_mouth', 12);
        }
        else if (idleAnimPlaying) {
          playChainedExpression('reaction2c_begin_transition', 'massage2_eyes', 'massage2_mouth', 12);
        }
        else {
          playChainedExpression('massage2_transition', 'massage2_eyes', 'massage2_mouth', 12);
        }
      }
      laughAnimPlaying = true;
    }
  }
  else if (maxPleasure > 750) {
    massageState1 = true;
    if (!laughAnimPlaying) {
      if (wasTeased) {
        if (tool === 'wand') {
          playChainedExpression('massage1a_tease_transition', 'massage1w_eyes', 'massage1w_mouth', 14);
        }
        else if (tool === 'tongue') {
          playChainedExpression('massage1t_tease_transition', 'massage1t_eyes', 'massage1t_mouth', 12);
        }
        else {
          playFullExpression('massage1_eyes', 'massage1_mouth', 10);
        }
      }
      else {
        if (tool === 'wand') {
          playChainedExpression('massage1w_transition', 'massage1w_eyes', 'massage1w_mouth', 14);
        }
        else if (tool === 'tongue') {
          playChainedExpression('massage1t_transition', 'massage1t_eyes', 'massage1t_mouth', 12);
        }
        else {
          playChainedExpression('massage1_transition', 'massage1_eyes', 'massage1_mouth', 10);
        }
      }
      laughAnimPlaying = true;
    }
  }
  else {
    massageState1 = true;
    if (!laughAnimPlaying) {
      if (wasTeased || idleAnimPlaying) {
        if (tool === 'wand') {
          playChainedExpression('massage1w_tease_transition', 'massage1w_eyes', 'massage1w_mouth', 14);
        }
        else if (tool === 'tongue') {
          playChainedExpression('massage1t_tease_transition', 'massage1t_eyes', 'massage1t_mouth', 12);
        }
        else {
          playFullExpression('massage1_eyes', 'massage1_mouth', 10);
        }
      }
      else {
        if (tool === 'wand') {
          playChainedExpression('massage1w_transition', 'massage1w_eyes', 'massage1w_mouth', 14);
        }
        else if (tool === 'tongue') {
          playChainedExpression('massage1t_transition', 'massage1t_eyes', 'massage1t_mouth', 12);
        }
        else if (tool === 'hands') {
          playChainedExpression('massage1_transition', 'massage1_eyes', 'massage1_mouth', 10);
        }
      }
      laughAnimPlaying = true;
    }
  }
  speechText.setText(currLaugh);
  //Rotate objects
  rotateObject(upperContainer, upperCenter, shakeSpeed, shakeCollided, shakeDirection, 1, 200);
  if (!toetied) {
    rotateObject(foot, footCenter, rotateSpeed, footCollided, footRotationDirection, 10, 100);
    rotateObject(altFoot, altFootCenter, .0002, idleCollided, altRotationDirection, 5, 100);
  }
  //Reset desperation
  desperation = 0;
  //Increase pleasure over time
  if (
    !broken &&
    !aroused &&
    (((pleasure === 1501 || pleasure === 1502) && massageState1) ||
      pleasure === 3498 ||
      pleasure === 3499)
  ) {
    laughAnimPlaying = false;
    pleasure += 1;
  }
  
  if (pleasure < 3505 && !broken) {
    pleasure++;
  }
  //If pleasure reaches 1000, reset maxDesperation
  if (pleasure > 1000) {
    maxDesperation = 0;
    broken = false;
  }
  //Set conditional for being massaged
  wasMassaged = true;
  wasTeased = false;
}

function scrunchFootMassage(leftAnim, rightAnim) {
  holdTimer.remove();
  reactionTimer.remove();
  teaseTimer = scene.time.addEvent({
    delay: 300,
    callback: function() {
      leftFoot.anims.remove();
      rightFoot.anims.remove();
      removeFaceAnims();
      laughAnimPlaying = false;
      if (!teaseAnimPlaying) {
        if (broken) {
          if (tool === 'tongue'){
            playTeaseAnim('massage1t_broken_tease_transition', 'tease1c_eyes', 'tease1c_mouth');
          }
          else {
            setStaticExpression('tease1c_eyes', 'tease1c_mouth');
          }
        }
        else if (aroused) {
          if (tool === 'tongue') {
            playTeaseAnim('massage3t_tease_transition', 'tease3c_eyes', 'tease3c_mouth', true);
          }
          else {
            playTeaseAnim('massage3_tease_transition', 'tease3c_eyes', 'tease3c_mouth');
          }
        }
        else if (maxPleasure > 1500) {
          if (tool === 'tongue') {
            playTeaseAnim('massage2t_tease_transition', 'tease2c_eyes', 'tease2c_mouth');
          }
          else {
            playTeaseAnim('massage2_tease_transition', 'tease2c_eyes', 'tease2c_mouth', true);
          }
        }
        else {
          if (tool === 'tongue'){
            playTeaseAnim('massage1t_tease_transition', 'tease1c_eyes', 'tease1c_mouth');
          }
          else {
            setStaticExpression('tease1c_eyes', 'tease1c_mouth');
          }
        }
      }

      teaseAnimPlaying = true;
      setMassageTeaseText();

      if (leftTickled) {
        leftFoot.play(leftAnim);
      }
      else if (rightTickled) {
        rightFoot.play(rightAnim);
      }
      still = true;
      wasTeased = true;
    },
    callbackScope: this
  });
  massageState1 = false;
  massageState2 = false;
  teaseTimerSet = true;
  reactionTimerSet = false;
}

function generateFootIdleAnim(foot) {
  animString = foot;
  if ( toetied ) {
    animString += 'Toetied';
  }
  if ( oiled ) {
    animString += 'Oiled';
  }
  animString += 'Idle'
  if ( !toetied ) {
    animString += Phaser.Math.Between(1, 3);
  }
  return animString;
}

function setTickleTeaseText() {
  if (broken) {
    speechText.setText(getRandomText(teasetext3));
  }
  else if (aroused) {
    speechText.setText(getRandomText(teasetext3c));
  }
  else if (desperation > 3000) {
    speechText.setText(getRandomText(teasetext2));
  }
  else if (desperation > 1300) {
    speechText.setText(getRandomText(teasetext));
  }
  else {
    speechText.setText(getRandomText(teasetext));
  }
}

function setMassageTeaseText() {
  if (broken) {
    speechText.setText(getRandomText(teasetext1c));
  }
  else if (aroused) {
    speechText.setText(getRandomText(teasetext3c));
  }
  else if (maxPleasure > 1500) {
    speechText.setText(getRandomText(teasetext2c));
  }
  else {
    speechText.setText(getRandomText(teasetext1c));
  }
}
