let config = {
  type: Phaser.AUTO,
  width: 1100,
  height: 750,
  'transparent': true,
  scene: {
    preload: preload,
    create: create,
    update: update
  }
};

let game = new Phaser.Game(config);
let scene;

function preload ()
{
  this.load.on('complete', () => {
    sizeButtons();
    removeLoadScreen();
  });
  main = this;
  loadAssets();
}

function create ()
{
  scene = this;
  createAssets();
  leftFoot.setInteractive();
  rightFoot.setInteractive();
  createAnimations();
  createTimers(this);

  //Speech and laugh text
  speechText = this.add.text(0, 0, '...',
  {
    fontFamily: 'custom, Helvetica',
    fontSize: 21,
    color: '#960018',
    stroke: '#000000',
    strokeThickness: 0,
    align: 'center',
    wordWrap: { width: 540, useAdvancedWrap: true }
  });
  
  //Add pointer event handlers to feet
  leftFoot.on('pointerover', function() {
    leftTickled = true;
    idleUpperSet = false;
  });

  rightFoot.on('pointerover', function() {
    rightTickled = true;
    idleUpperSet = false;
  });

  //On pointerout, if tired, set next tired-text line to be displayed and update next speech line to be displayed
  //Set givenBreak to true to reset special speech line
  leftFoot.on('pointerout', function() {
    leftTickled = false;
    footAnimPlaying = false;
    leftFoot.anims.remove('tickleLeft');
    leftFoot.anims.remove('scrunchLeft');
    if (!toetied) {
      if (oiled) {
        leftFoot.setTexture('leftFootOiled');
      }
      else {
        leftFoot.setTexture('leftFoot');
      }
    }
    else {
      if (oiled) {
        leftFoot.setTexture('leftFootTiedOiled');
      }
      else {
        leftFoot.setTexture('leftFootTied');
      }
    }
    if (desperation > 3000 || broken) {
      currBreathe = getRandomText(tiredtext2);
    }
    else {
      currBreathe = getRandomText(tiredtext);
    }
    breakTimer = scene.time.addEvent({
      delay: 500,
      callback: function() {
        givenBreak = true;
        updateLaugh();
      },
      callbackScope: scene
    });
  });

  rightFoot.on('pointerout', function() {
    rightTickled = false;
    footAnimPlaying = false;
    rightFoot.anims.remove('tickleRight');
    rightFoot.anims.remove('scrunchRight');
    if (!toetied) {
      if (oiled) {
        rightFoot.setTexture('rightFootOiled');
      }
      else {
        rightFoot.setTexture('rightFoot');
      }
    }
    else {
      if (oiled) {
        rightFoot.setTexture('rightFootTiedOiled');
      }
      else {
        rightFoot.setTexture('rightFootTied');
      }
    }
    if (desperation > 3000 || broken) {
      currBreathe = getRandomText(tiredtext2);
    }
    else {
      currBreathe = getRandomText(tiredtext);
    }
    breakTimer = scene.time.addEvent({
      delay: 500,
      callback: function() {
        givenBreak = true;
        updateLaugh();
      },
      callbackScope: scene
    });
  });
}

function update()
{
  //Get position and rate of change of mouse coordinates
  x1 = x2;
  y1 = y2;
  x2 = this.input.x;
  y2 = this.input.y;
  dx = x2 - x1;
  dy = y2 - y1;

  updateTool(x2, y2, dy);

  if (!givenBreak || desperation >= 1300) {
    toggleButtonUse('.outfitButton', false);
    toggleButtonUse('#blindfoldButton', false);
    toggleButtonUse('#gagButton', false);
  }
  else {
    toggleButtonUse('.outfitButton', true);
    toggleButtonUse('#blindfoldButton', true, blindfold.visible ? '#5A000E' : '#960018');
    toggleButtonUse('#gagButton', true, gagged ? '#5A000E' : '#960018');
  }

  //If mode in 'tickle' call tickleUpdate function
  if (mode == 'tickle') {
    leftFoot.setInteractive();
    rightFoot.setInteractive();
    tickleUpdate();
  }
  //Else if mode in 'massage' and currently not tired, call massageUpdate function
  else if (mode == 'massage' && desperation < 1250) {
    leftFoot.setInteractive();
    rightFoot.setInteractive();
    massageUpdate();
  }
  //If mode in 'massage' and is currently tired, default to tickleUpdate and remove interaction of feet
  else {
    leftFoot.removeInteractive();
    rightFoot.removeInteractive();
    tickleUpdate();
  }
  Phaser.Display.Align.In.Center(speechText, textbox);
  //console.log(mode + ' ' + desperation + ' ' + maxDesperation + ' ' + pleasure + ' ' + maxPleasure);
}
